@@ -20,7 +20,7 @@ from weatherbitpypi.data_classes import (
 
 _LOGGER = logging.getLogger(__name__)
 
-class Api:
+class Weatherbit:
     """Weatherbit Current Conditions Client."""
 
     def __init__(
@@ -30,7 +30,7 @@ class Api:
         longitude: float,
         language: str="en",
         units: str = "M",
-        session: Optional[ClientSession] = None
+        session: Optional[ClientSession] = None,
         ):
         self._api_key = api_key
         self._latitude = latitude
